@@ -1,3 +1,10 @@
+#!/usr/bin/perl
+
+use v5.14;
+use warnings;
+
+use Future::AsyncAwait 0.47;
+
 use IO::Async::Loop;
 use Net::Async::IRC;
 
@@ -13,11 +20,11 @@ my $irc = Net::Async::IRC->new(
 
 $loop->add( $irc );
 
-$irc->login(
+await $irc->login(
    nick => "MyName",
    host => "irc.example.org",
-)->get;
+);
 
-$irc->do_PRIVMSG( target => "YourName", text => "Hello world!" );
+await $irc->do_PRIVMSG( target => "YourName", text => "Hello world!" );
 
 $loop->run;
