@@ -1,6 +1,10 @@
-use strict;
+#!/usr/bin/perl
+
+use v5.14;
 use warnings;
 
+use Future::AsyncAwait 0.47; # toplevel await
+
 use IO::Async::Loop;
 use Net::Async::IRC;
 
@@ -13,12 +17,12 @@ my $SERVER = "irc.example.net";
 my $NICK = "MyNick";
 my $TARGET = "TargetNick";
 
-$irc->login(
+await $irc->login(
    host => $SERVER,
    nick => $NICK,
-)->then( sub {
-   $irc->do_PRIVMSG(
-      target => $TARGET,
-      text   => "Hello, World"
-   );
-})->get;
+);
+
+await $irc->do_PRIVMSG(
+   target => $TARGET,
+   text   => "Hello, World"
+);
