@@ -1,6 +1,10 @@
-use strict;
+#!/usr/bin/perl
+
+use v5.14;
 use warnings;
 
+use Future::AsyncAwait 0.47; # toplevel await
+
 use IO::Async::Loop;
 use Net::Async::IRC;
 
@@ -13,10 +17,10 @@ my $SERVER = "irc.example.net";
 my $NICK = "MyNick";
 my $TARGET = "TargetNick";
 
-$irc->login(
+await $irc->login(
    host => $SERVER,
    nick => $NICK,
-)->get;
+);
 
 my $target_folded = $irc->casefold_name( $TARGET );
 
@@ -35,7 +39,7 @@ $irc->configure(
    },
 );
 
-$irc->do_PRIVMSG(
+await $irc->do_PRIVMSG(
    target => $TARGET,
    text   => "Hello, what's your name?"
 );
